@@ -3,15 +3,15 @@ use warnings;
 use strict;
 use Carp;
 
+our $VERSION = '0.002';
+
 use base 'Test::Smoke::ObjectBase';
 use Test::Smoke::LogMixin;
 
-use fallback 'inc';
-
 require Test::Smoke;
 
 use File::Spec::Functions;
-use JSON;
+use Test::Smoke::Util::LoadAJSON;
 
 =head1 NAME
 
@@ -143,8 +143,15 @@ HTTP or Test::Smoke::Gateway-application errors.
 
 sub post {
     my $self = shift;
-    my $response_body = eval {decode_json($self->_post_data())};
-    confess($@) if $@;
+
+    my $response = eval { $self->_post_data() };
+    confess("[POST]: >$response< " . $@) if $@;
+
+    my $response_body = eval {
+        Test::Smoke::Util::LoadAJSON->new->utf8->allow_nonref->decode($response);
+    };
+    confess("[decode_json] >$response< " . $@) if $@;
+
     $self->_process_post_result($response_body);
 }
 
